@@ -39,7 +39,7 @@
 #define GAMMA       2.0       /* expansion coefficient */
 
 
-double simplex2(double (*func)(int, int, int, double *, double *, int *, double ***, double *, double **, double **, int, int), int n1, int p, int T, double *la, int *index, double ***X, double *gamma_k, double **invSk, double **invPsik, double *start, double EPSILON, double scale, int Mu_type, int trans_type)
+double simplex2(double (*func)(int, int, int, double *, double *, double ***, double *, double **, double **, int, int), int n1, int p, int T, double *la, double ***X, double *gamma_k, double **invSk, double **invPsik, double *start, double EPSILON, double scale, int Mu_type, int trans_type)
 {
   
   int vs;        	/* vertex with smallest value */
@@ -63,13 +63,9 @@ double simplex2(double (*func)(int, int, int, double *, double *, int *, double
   double min;
   
   double fsum,favg,s,cent;
-  n = 0;
-  for(j=0;j<T;j++){
-    if(index[j]==1){
-	n +=1;
-    }
-  }
-  
+
+
+  n = T;  
   /* dynamically allocate arrays */
   
   /* allocate the rows of the arrays */
@@ -120,7 +116,7 @@ double simplex2(double (*func)(int, int, int, double *, double *, int *, double
   
   /* find the initial function values */
   for (j=0;j<=n;j++) {
-    f[j] = func(n1, p, T, v[j], la, index, X, gamma_k, invSk, invPsik, Mu_type, trans_type);
+    f[j] = func(n1, p, T, v[j], la, X, gamma_k, invSk, invPsik, Mu_type, trans_type);
   }
   
   k = n+1;
@@ -167,7 +163,7 @@ double simplex2(double (*func)(int, int, int, double *, double *, int *, double
     for (j=0;j<=n-1;j++) {
       vr[j] = (1+ALPHA)*vm[j] - ALPHA*v[vg][j];
     }
-    fr = func(n1, p, T, vr, la, index, X, gamma_k, invSk, invPsik, Mu_type, trans_type);
+    fr = func(n1, p, T, vr, la, X, gamma_k, invSk, invPsik, Mu_type, trans_type);
     k++;
     
     /* added <= */
@@ -184,7 +180,7 @@ double simplex2(double (*func)(int, int, int, double *, double *, int *, double
       for (j=0;j<=n-1;j++) {
 	ve[j] = GAMMA*vr[j] + (1-GAMMA)*vm[j];
       }
-      fe = func(n1, p, T, ve, la, index, X, gamma_k, invSk, invPsik, Mu_type, trans_type);
+      fe = func(n1, p, T, ve, la, X, gamma_k, invSk, invPsik, Mu_type, trans_type);
       k++;
       
    
@@ -207,7 +203,7 @@ double simplex2(double (*func)(int, int, int, double *, double *, int *, double
       for (j=0;j<=n-1;j++) {
 	vc[j] = BETA*v[vg][j] + (1-BETA)*vm[j];
       }
-      fc = func(n1, p, T, vc, la, index, X, gamma_k, invSk, invPsik, Mu_type, trans_type);
+      fc = func(n1, p, T, vc, la, X, gamma_k, invSk, invPsik, Mu_type, trans_type);
       k++;
       if (fc < f[vg]) {
 	for (j=0;j<=n-1;j++) {
@@ -228,9 +224,9 @@ double simplex2(double (*func)(int, int, int, double *, double *, int *, double
 	    }
 	  }
 	}
-	f[vg] = func(n1, p, T, v[vg], la, index, X, gamma_k, invSk, invPsik, Mu_type, trans_type);
+	f[vg] = func(n1, p, T, v[vg], la, X, gamma_k, invSk, invPsik, Mu_type, trans_type);
 	k++;
-	f[vh] = func(n1, p, T, v[vh], la, index, X, gamma_k, invSk, invPsik, Mu_type, trans_type);
+	f[vh] = func(n1, p, T, v[vh], la, X, gamma_k, invSk, invPsik, Mu_type, trans_type);
 	k++;
 	
 	
@@ -266,7 +262,7 @@ double simplex2(double (*func)(int, int, int, double *, double *, int *, double
   for (j=0;j<n;j++) {
     start[j] = v[vs][j];
   }
-  min=func(n1, p, T, v[vs], la, index, X, gamma_k, invSk, invPsik, Mu_type, trans_type);
+  min=func(n1, p, T, v[vs], la, X, gamma_k, invSk, invPsik, Mu_type, trans_type);
   k++;
 
 
